@@ -5,6 +5,8 @@ TOKENS = "tokens"
 INTENT_NAME_KEY = "name"
 PREDICTED_CONFIDENCE_KEY = "confidence"
 ENTITIES = "entities"
+INPUT_IDS = "input_ids"
+ATTENTION_MASKS = "attention_masks"
 # PIPELINE
 
 KEY_PIPELINE = "pipeline"
